@@ -1,8 +1,6 @@
 from django.apps import apps
 from django.conf import settings
-import reversion
 import json
-import requests
 
 from django.contrib.contenttypes.fields import GenericForeignKey
 from django.contrib.contenttypes.models import ContentType
